﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace JavascriptWebResourcesManager.DelegatesHelpers
{
    public class TreeViewDelegates
    {
        public static TreeNodeCollection GetNodes(TreeView treeview)
        {
            TreeNodeCollection collection = null;

            MethodInvoker mi = delegate
            {
                collection = treeview.Nodes;
            };

            if (treeview.InvokeRequired)
            {
                treeview.Invoke(mi);
            }
            else
            {
                mi();
            }
            
            return collection;
        }

        public static TreeNode GetSelectedNode(TreeView treeview)
        {
            TreeNode node = null;

            MethodInvoker mi = delegate
            {
                node = treeview.SelectedNode;
            };

            if (treeview.InvokeRequired)
                treeview.Invoke(mi);
            else
                mi();

            return node;
        }

        public static void ClearNodes(TreeView treeview)
        {
            MethodInvoker mi = delegate
            {
                treeview.Nodes.Clear();
            };

            if (treeview.InvokeRequired)
            {
                treeview.Invoke(mi);
            }
            else
            {
                mi();
            }
        }

        public static void ExpandAll(TreeView treeview)
        {
            MethodInvoker mi = delegate
            {
                treeview.ExpandAll();
            };

            if (treeview.InvokeRequired)
            {
                treeview.Invoke(mi);
            }
            else
            {
                mi();
            }
        }

        public static void AddNode(TreeView treeview, TreeNode node)
        {
            MethodInvoker mi = delegate
            {
                treeview.Nodes.Add(node);
            };

            if (treeview.InvokeRequired)
            {
                treeview.Invoke(mi);
            }
            else
            {
                mi();
            }
        }

        public static void AddNode(TreeNode parentNode, TreeNode node)
        {
            MethodInvoker mi = delegate
            {
                parentNode.Nodes.Add(node);
            };

            if (parentNode.TreeView.InvokeRequired)
            {
                parentNode.TreeView.Invoke(mi);
            }
            else
            {
                mi();
            }
        }

        public static bool IsSelected(TreeNode node)
        {
            bool result = false;

            MethodInvoker mi = delegate
            {
                result = node.IsSelected;
            };

            if (node.TreeView.InvokeRequired)
            {
                node.TreeView.Invoke(mi);
            }
            else
            {
                mi();
            }

            return result;
        }
    }
}
