﻿using System;
using System.IO;
using System.Xml;
using Microsoft.Crm.Sdk.Messages;
using Microsoft.Xrm.Sdk;
using Microsoft.Xrm.Sdk.Metadata;
using Microsoft.Xrm.Sdk.Query;

namespace JavascriptWebResourcesManager
{
    class SolutionManager
    {
        #region Variables

        /// <summary>
        /// Organization service
        /// </summary>
        IOrganizationService service;

        /// <summary>
        /// Current retrieved solution
        /// </summary>
        Entity currentSolution;

       #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of class SolutionManager
        /// </summary>
        /// <param name="organizationService">Organization service</param>
        public SolutionManager(IOrganizationService organizationService)
        {
            this.service = organizationService;
        }

        #endregion

        #region Properties

        public Entity CurrentSolution
        {
            get { return currentSolution; }
            set { currentSolution = value; }
        }

        #endregion

        public void AddComponent(int type, Guid id)
        {
            try
            {
                // Adding Component to server solution
                AddSolutionComponentRequest request = new AddSolutionComponentRequest()
                {
                    ComponentType = type,
                    SolutionUniqueName = currentSolution["uniquename"].ToString(),
                    ComponentId = id
                };

                this.service.Execute(request);
            }
            catch (Exception error)
            {
                throw new Exception("Error while adding solution component: " + error.Message);
            }
        }

        public string GetSolutionPrefix(Guid publisherId)
        {
            Entity publisher = this.service.Retrieve("publisher", publisherId, new ColumnSet(true));

            return publisher["customizationprefix"].ToString();
        }
    }
}
